@@ -1,6 +1,6 @@
 package App::mkfeyorm;
 BEGIN {
-  $App::mkfeyorm::VERSION = '0.004';
+  $App::mkfeyorm::VERSION = '0.005';
 }
 # ABSTRACT: Make skeleton code with Fey::ORM
 
@@ -69,6 +69,12 @@ has 'table_template' => (
     default => $TABLE_TEMPLATE,
 );
 
+has 'cache' => (
+    is      => 'ro',
+    isa     => 'Bool',
+    default => 0,
+);
+
 has '_template' => (
     is         => 'ro',
     isa        => 'Template',
@@ -114,8 +120,9 @@ sub _process_schema {
     } @{$self->tables};
 
     my $vars = {
-        SCHEMA    => $schema,
-        TABLES    => \@tables,
+        SCHEMA => $schema,
+        TABLES => \@tables,
+        CACHE  => $self->cache,
     };
 
     $self->_template->process(
@@ -157,6 +164,7 @@ sub _process_table {
     my $vars = {
         SCHEMA   => $schema,
         TABLE    => $table,
+        CACHE    => $self->cache,
         DB_TABLE => $db_table,
     };
 
@@ -188,7 +196,7 @@ App::mkfeyorm - Make skeleton code with Fey::ORM
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -258,6 +266,11 @@ If you want to use your own template file then use this attribute.
 Table template file. Default is C<table.tt>.
 If you want to use your own template file then use this attribute.
 
+=head2 cache
+
+Use cache feature or not. Default is false.
+It uses L<Storable> to save and load cache file.
+
 =head1 METHODS
 
 =head2 process
